# Bedrijfsgegevens

Please fill out your company details on this form. The data on this form will also appear in the report.

Naam bedrijf
Bezoekadres bedrijf
Postadres bedrijf (More information) Address
Postal Code
City
E-mailadres (More information) Telefoonnummer Bedrijfsactiviteit Naam invuller Functie invuller Afdeling Lokatie
Datum (Datum waarop de gegevens verzameld zijn) Day Month
Year
Aantal personeelsleden in dienst Maximaal 40 uur betaalde arbeid per week
(alle werknemers samen) Maximaal 25 werknemers
(let op het gaat hier niet om FTE’s, maar om daadwerkelijke personen) Meer dan 25 werknemers
(let op het gaat hier niet om FTE’s, maar om daadwerkelijke personen)
Verzuimpercentage Aantal ongevallen vorig jaar Aantal mensen in WIA vorig jaar Gegevens arbodienst/-deskundige
(naam, contactpersoon, adres, postcode, plaats, e-mail)

Akkoord OR/medewerkersvertegenwoordiging
Datum van akkoord OR/medewerkersvertegenwoordiging Day Month
Year

1. Voorbereiden
2. Inventariseren
3. Evalueren
4. Plan van aanpak
5. Rapporten

Link to sector organisation | Disclaimer | Design by Cornae